==> aloe-1.4.tar.gz: aloe-1.4/modules/wimax_DECODLDPC/src/my_prog.c <==
/** Sample ALOE component implementation file
    Specific module code
*/

/** Include general data type library */
#include "typetools.h"
#include "itf_types.h"


/** Required include according original code need*/
#include "dec_LDPC.h"

/*GLOBAL VARIABLES & BUFFERS*/
int value;
extern max_iter;
//extern _EbN0;
extern N;

#define BUFFERSIZE  100*1024

/** Initialization: At INIT PHASE*/
void init_my_prog()
{
        pchk_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.pchk";
	gen_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.gen";
//        pchk_file = "../data/802_16e.pchk";
//	gen_file = "data/802_16e.gen";
	printf("DecodeLDPC Init:");
	Init_DeLDPC();
	printf(" OK\n");
}


/** RUN PHASE
 *  Module function generic format
 *  Returns the output length or -1 if error
 */
int my_prog(void *pdatain, void *pdataout,\
            int processingtypeIN, int processingtypeOUT, 
            int inputlength, ControlMODULENAME_h myctrl)
{

    int i, outputlength;
    float *input_f, *output_f;
    char *input_c, *output_c;
    int *input_i, *output_i;
    short *input_s, *output_s;

    char info_out_chars[BUFFERSIZE];

    /**Properly typecast your input data pointer and check the input data type*/
    if(processingtypeIN==TYPE_FLOAT)input_f=(float *)pdatain;
    else if(processingtypeIN==TYPE_BIT8)input_c=(char *)pdatain;
        else{
            printf("wimax_DECODLDPC.my_prog(): ERROR INPUT DATA TYPE NON VALID\n");
            return(-1);
        }

    if(processingtypeOUT==TYPE_BIT8)output_c=(char *)pdataout;
    else {
        printf("wimax_DECODLDPC.my_prog(): ERROR OUTPUT DATA TYPE NON VALID\n");
        return(-1);
    }

    max_iter = myctrl.iters;
    _EbN0 = myctrl.EbN0;


    //*YOUR CODE*/
    /** ONLY FOR TESTING PURPOSES: MODULATE BPSK*/
    if(processingtypeIN==TYPE_BIT8)
        for(i=0; i<inputlength; i++)*(input_f+i)=(float)(1-(2**(input_c+i)));

    /** Decode word Input_i to output_i*/
    run_decode_LDPC(input_f,info_out_chars);

    /** Only Relevant Data out*/
    outputlength=(int)(inputlength*myctrl.coderate);
    for(i=1152; i<N; i++){
        if (info_out_chars[cols[i]] == 0) output_c[i-1152]=0;
	else output_c[i-1152]=1;
    }

    return(outputlength);
}

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/wimax_DECODLDPC/src/my_prog.c <==
/** Sample ALOE component implementation file
    Specific module code
*/

/** Include general data type library */
#include "typetools.h"
#include "itf_types.h"


/** Required include according original code need*/
#include "dec_LDPC.h"

/*GLOBAL VARIABLES & BUFFERS*/
int value;
extern max_iter;
//extern _EbN0;
extern N;

#define BUFFERSIZE  100*1024

/** Initialization: At INIT PHASE*/
void init_my_prog()
{
//        pchk_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.pchk";
//	gen_file = "/home/antoni/DADES/WORK/LDPC/repository/data/802_16e.gen";
        pchk_file = "/home/ismael/work/phal_1.4/example-repository/data/802_16e.pchk";
	gen_file = "/home/ismael/work/phal_1.4/example-repository/data/802_16e.gen";
	printf("DecodeLDPC Init:");
	Init_DeLDPC();
	printf(" OK\n");
}


/** RUN PHASE
 *  Module function generic format
 *  Returns the output length or -1 if error
 */
int my_prog(void *pdatain, void *pdataout,\
            int processingtypeIN, int processingtypeOUT, 
            int inputlength, ControlMODULENAME_h myctrl)
{

    int i, outputlength;
    float *input_f, *output_f;
    char *input_c, *output_c;
    int *input_i, *output_i;
    short *input_s, *output_s;

    char info_out_chars[BUFFERSIZE];

    /**Properly typecast your input data pointer and check the input data type*/
    if(processingtypeIN==TYPE_FLOAT)input_f=(float *)pdatain;
    else if(processingtypeIN==TYPE_BIT8)input_c=(char *)pdatain;
        else{
            printf("wimax_DECODLDPC.my_prog(): ERROR INPUT DATA TYPE NON VALID\n");
            return(-1);
        }

    if(processingtypeOUT==TYPE_BIT8)output_c=(char *)pdataout;
    else {
        printf("wimax_DECODLDPC.my_prog(): ERROR OUTPUT DATA TYPE NON VALID\n");
        return(-1);
    }

    max_iter = myctrl.iters;
    _EbN0 = myctrl.EbN0;


    //*YOUR CODE*/
    /** ONLY FOR TESTING PURPOSES: MODULATE BPSK*/
    if(processingtypeIN==TYPE_BIT8)
        for(i=0; i<inputlength; i++)*(input_f+i)=(float)(1-(2**(input_c+i)));

    /** Decode word Input_i to output_i*/
    run_decode_LDPC(input_f,info_out_chars);

    /** Only Relevant Data out*/
    outputlength=(int)(inputlength*myctrl.coderate);
    for(i=1152; i<N; i++){
        if (info_out_chars[cols[i]] == 0) output_c[i-1152]=0;
	else output_c[i-1152]=1;
    }

    return(outputlength);
}
